IntExtensions extension

Provides extended methods for int.

int用の拡張メソッドを提供します。

on

Properties

isEmpty bool

Available on int, provided by the IntExtensions extension

Returns true if int is 0.
no setter
isNotEmpty bool

Available on int, provided by the IntExtensions extension

Returns true if int is not 0.
no setter

Methods

format(String format) String

Available on int, provided by the IntExtensions extension

Enter format to replace the value of int with a string.
limit(int min, int max) int

Available on int, provided by the IntExtensions extension

If int is less than or equal to min, min is returned.
limitHigh(int max) int

Available on int, provided by the IntExtensions extension

If int is greater than or equal to max, max is returned.
limitLow(int min) int

Available on int, provided by the IntExtensions extension

If int is less than or equal to min, min is returned.
replaceNanOrInfinite([int replace = 0]) int

Available on int, provided by the IntExtensions extension

If int is double.nan, double.infinity, or double.negativeInfinity, replace it with replace.